@@ -3,12 +3,23 @@
 # Author: Dmitry Shachnev, 2013
 # License: BSD
 
+"""This file provides quick access to all SecretStorage API. Please
+refer to documentation of individual modules for API details.
+
+It also provides some functions for compatibility with older
+SecretStorage releases. Those functions are not recommended for use
+in new software."""
+
 import dbus
 from secretstorage.collection import Collection, create_collection, \
-get_all_collections, get_collection_by_alias, search_items
+ get_all_collections, get_default_collection, get_any_collection, \
+ get_collection_by_alias, search_items
 from secretstorage.item import Item
+from secretstorage.exceptions import SecretStorageException, \
+ SecretServiceNotAvailableException, LockedException, \
+ ItemNotFoundException
 
-__version__ = '0.9.0'
+__version__ = '1.0.0'
 
 def dbus_init(main_loop=True, use_qt_loop=False):
 	"""Returns new SessionBus_. If `main_loop` is :const:`True`, registers
