@@ -12,9 +12,10 @@ class ExceptionsTest(unittest.TestCase):
 	"""A test case that ensures that all SecretStorage exceptions
 	are raised correctly."""
 
-	def setUp(self):
-		self.bus = secretstorage.dbus_init(main_loop=False)
-		self.collection = secretstorage.Collection(self.bus)
+	@classmethod
+	def setUpClass(cls):
+		cls.bus = secretstorage.dbus_init(main_loop=False)
+		cls.collection = secretstorage.Collection(cls.bus)
 
 	def test_double_deleting(self):
 		item = self.collection.create_item('MyItem',
@@ -25,6 +26,11 @@ class ExceptionsTest(unittest.TestCase):
 	def test_non_existing_item(self):
 		self.assertRaises(ItemNotFoundException, secretstorage.Item,
 			self.bus, '/not/existing/path')
+	
+	def test_non_existing_collection(self):
+		self.assertRaises(ItemNotFoundException,
+			secretstorage.get_collection_by_alias,
+			self.bus, 'non-existing-alias')
 
 if __name__ == '__main__':
 	unittest.main()
